""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core.typesystem import schema, fields


class GlobalSSHAreaSchema(schema.ResponseSchema):
    """GlobalSSHArea -"""

    fields = {
        "Area": fields.Str(required=True, load_from="Area"),
        "AreaCode": fields.Str(required=True, load_from="AreaCode"),
        "RegionSet": fields.List(fields.Str()),
    }


class GlobalSSHInfoSchema(schema.ResponseSchema):
    """GlobalSSHInfo - GlobalSSH实例信息"""

    fields = {
        "AcceleratingDomain": fields.Str(
            required=True, load_from="AcceleratingDomain"
        ),
        "Area": fields.Str(required=True, load_from="Area"),
        "BandwidthPackage": fields.Int(
            required=False, load_from="BandwidthPackage"
        ),
        "ChargeType": fields.Str(required=True, load_from="ChargeType"),
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "Expire": fields.Bool(required=True, load_from="Expire"),
        "ExpireTime": fields.Int(required=True, load_from="ExpireTime"),
        "ForwardRegion": fields.Str(required=False, load_from="ForwardRegion"),
        "GlobalSSHPort": fields.Int(required=True, load_from="GlobalSSHPort"),
        "InstanceId": fields.Str(required=True, load_from="InstanceId"),
        "InstanceType": fields.Str(required=True, load_from="InstanceType"),
        "Port": fields.Int(required=True, load_from="Port"),
        "Remark": fields.Str(required=True, load_from="Remark"),
        "TargetIP": fields.Str(required=True, load_from="TargetIP"),
    }


class LineDetailSchema(schema.ResponseSchema):
    """LineDetail - 子线路"""

    fields = {
        "LineFrom": fields.Str(required=True, load_from="LineFrom"),
        "LineFromName": fields.Str(required=True, load_from="LineFromName"),
        "LineId": fields.Str(required=False, load_from="LineId"),
        "LineTo": fields.Str(required=True, load_from="LineTo"),
        "LineToName": fields.Str(required=True, load_from="LineToName"),
    }


class UGAALineSchema(schema.ResponseSchema):
    """UGAALine - UGAA加速线路"""

    fields = {
        "LineDetail": fields.List(LineDetailSchema()),
        "LineFrom": fields.Str(required=True, load_from="LineFrom"),
        "LineFromName": fields.Str(required=True, load_from="LineFromName"),
        "LineId": fields.Str(required=False, load_from="LineId"),
        "LineTo": fields.Str(required=True, load_from="LineTo"),
        "LineToName": fields.Str(required=True, load_from="LineToName"),
        "MaxBandwidth": fields.Int(required=True, load_from="MaxBandwidth"),
    }


class SSLBindedTargetSetSchema(schema.ResponseSchema):
    """SSLBindedTargetSet - Describle SSL Bind UAG Info"""

    fields = {
        "ResourceId": fields.Str(required=True, load_from="ResourceId"),
        "ResourceName": fields.Str(required=False, load_from="ResourceName"),
    }


class PathXSSLSetSchema(schema.ResponseSchema):
    """PathXSSLSet - Describle PathX SSL"""

    fields = {
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "ExpireTime": fields.Int(required=False, load_from="ExpireTime"),
        "SSLBindedTargetSet": fields.List(SSLBindedTargetSetSchema()),
        "SSLContent": fields.Str(required=False, load_from="SSLContent"),
        "SSLId": fields.Str(required=False, load_from="SSLId"),
        "SSLMD5": fields.Str(required=False, load_from="SSLMD5"),
        "SSLName": fields.Str(required=False, load_from="SSLName"),
        "SourceType": fields.Int(required=False, load_from="SourceType"),
        "SubjectName": fields.Str(required=False, load_from="SubjectName"),
    }


class ForwardAreaSchema(schema.ResponseSchema):
    """ForwardArea - 全地域加速源站区域"""

    fields = {
        "Area": fields.Str(required=True, load_from="Area"),
        "AreaCode": fields.Str(required=True, load_from="AreaCode"),
        "ContinentCode": fields.Str(required=True, load_from="ContinentCode"),
        "CountryCode": fields.Str(required=True, load_from="CountryCode"),
        "FlagEmoji": fields.Str(required=True, load_from="FlagEmoji"),
        "FlagUnicode": fields.Str(required=True, load_from="FlagUnicode"),
    }


class SrcAreaInfoSchema(schema.ResponseSchema):
    """SrcAreaInfo - 接入地域信息"""

    fields = {
        "Area": fields.Str(required=True, load_from="Area"),
        "AreaCode": fields.Str(required=True, load_from="AreaCode"),
        "FlagEmoji": fields.Str(required=True, load_from="FlagEmoji"),
        "FlagUnicode": fields.Str(required=True, load_from="FlagUnicode"),
    }


class AccelerationAreaInfosSchema(schema.ResponseSchema):
    """AccelerationAreaInfos - 加速大区信息"""

    fields = {
        "AccelerationArea": fields.Str(
            required=True, load_from="AccelerationArea"
        ),
        "AccelerationNodes": fields.List(SrcAreaInfoSchema()),
    }


class ForwardTaskSchema(schema.ResponseSchema):
    """ForwardTask - 全球统一接入转发端口任务信息"""

    fields = {
        "Port": fields.Int(required=True, load_from="Port"),
        "Protocol": fields.Str(required=True, load_from="Protocol"),
        "RSPort": fields.Int(required=True, load_from="RSPort"),
    }


class OutPublicIpInfoSchema(schema.ResponseSchema):
    """OutPublicIpInfo - 线路回源IP信息"""

    fields = {
        "Area": fields.Str(required=False, load_from="Area"),
        "IP": fields.Str(required=False, load_from="IP"),
    }


class ForwardInfoSchema(schema.ResponseSchema):
    """ForwardInfo - 全球统一接入加速实例配置信息"""

    fields = {
        "AccelerationArea": fields.Str(
            required=True, load_from="AccelerationArea"
        ),
        "AccelerationAreaInfos": fields.List(AccelerationAreaInfosSchema()),
        "AccelerationAreaName": fields.Str(
            required=True, load_from="AccelerationAreaName"
        ),
        "Bandwidth": fields.Int(required=True, load_from="Bandwidth"),
        "CName": fields.Str(required=True, load_from="CName"),
        "ChargeType": fields.Str(required=True, load_from="ChargeType"),
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "Domain": fields.Str(required=False, load_from="Domain"),
        "EgressIpList": fields.List(OutPublicIpInfoSchema()),
        "ExpireTime": fields.Int(required=True, load_from="ExpireTime"),
        "IPList": fields.List(fields.Str()),
        "InstanceId": fields.Str(required=True, load_from="InstanceId"),
        "Name": fields.Str(required=True, load_from="Name"),
        "OriginArea": fields.Str(required=True, load_from="OriginArea"),
        "OriginAreaCode": fields.Str(required=True, load_from="OriginAreaCode"),
        "PortSets": fields.List(ForwardTaskSchema()),
        "Remark": fields.Str(required=False, load_from="Remark"),
    }


class NodeDelaysSchema(schema.ResponseSchema):
    """NodeDelays - 全地域加速各个区域加速延迟情况"""

    fields = {
        "Area": fields.Str(required=True, load_from="Area"),
        "AreaCode": fields.Str(required=True, load_from="AreaCode"),
        "CountryCode": fields.Str(required=True, load_from="CountryCode"),
        "FlagEmoji": fields.Str(required=True, load_from="FlagEmoji"),
        "FlagUnicode": fields.Str(required=True, load_from="FlagUnicode"),
        "Latency": fields.Float(required=True, load_from="Latency"),
        "LatencyInternet": fields.Float(
            required=True, load_from="LatencyInternet"
        ),
        "LatencyOptimization": fields.Float(
            required=True, load_from="LatencyOptimization"
        ),
        "Loss": fields.Float(required=True, load_from="Loss"),
        "LossInternet": fields.Float(required=True, load_from="LossInternet"),
        "LossOptimization": fields.Float(
            required=True, load_from="LossOptimization"
        ),
    }


class AccelerationInfoSchema(schema.ResponseSchema):
    """AccelerationInfo - 加速提升信息"""

    fields = {
        "AccelerationArea": fields.Str(
            required=True, load_from="AccelerationArea"
        ),
        "AccelerationName": fields.Str(
            required=True, load_from="AccelerationName"
        ),
        "NodeInfo": fields.List(NodeDelaysSchema()),
    }


class UPathSetSchema(schema.ResponseSchema):
    """UPathSet - uga关联的upath信息"""

    fields = {
        "Bandwidth": fields.Int(required=False, load_from="Bandwidth"),
        "LineFrom": fields.Str(required=False, load_from="LineFrom"),
        "LineFromName": fields.Str(required=False, load_from="LineFromName"),
        "LineId": fields.Str(required=False, load_from="LineId"),
        "LineTo": fields.Str(required=False, load_from="LineTo"),
        "LineToName": fields.Str(required=False, load_from="LineToName"),
        "UPathId": fields.Str(required=False, load_from="UPathId"),
        "UPathName": fields.Str(required=False, load_from="UPathName"),
    }


class UGAATaskSchema(schema.ResponseSchema):
    """UGAATask - 用户在UGAA实例下配置的多端口任务"""

    fields = {
        "Port": fields.Int(required=True, load_from="Port"),
        "Protocol": fields.Str(required=True, load_from="Protocol"),
    }


class UGAL7ForwarderSchema(schema.ResponseSchema):
    """UGAL7Forwarder - UGA实例 7层转发器信息"""

    fields = {
        "Port": fields.Int(required=True, load_from="Port"),
        "Protocol": fields.Str(required=True, load_from="Protocol"),
        "RSPort": fields.Int(required=True, load_from="RSPort"),
        "SSLId": fields.Str(required=False, load_from="SSLId"),
        "SSLName": fields.Str(required=False, load_from="SSLName"),
    }


class UGAL4ForwarderSchema(schema.ResponseSchema):
    """UGAL4Forwarder - UGA实例 4层转发器信息"""

    fields = {
        "Port": fields.Int(required=True, load_from="Port"),
        "Protocol": fields.Str(required=True, load_from="Protocol"),
        "RSPort": fields.Int(required=True, load_from="RSPort"),
    }


class UGAAInfoSchema(schema.ResponseSchema):
    """UGAAInfo - 全球加速实例信息"""

    fields = {
        "CName": fields.Str(required=True, load_from="CName"),
        "Domain": fields.Str(required=False, load_from="Domain"),
        "IPList": fields.List(fields.Str()),
        "L4ForwarderSet": fields.List(UGAL4ForwarderSchema()),
        "L7ForwarderSet": fields.List(UGAL7ForwarderSchema()),
        "Location": fields.Str(required=False, load_from="Location"),
        "OutPublicIpList": fields.List(OutPublicIpInfoSchema()),
        "TaskSet": fields.List(UGAATaskSchema()),
        "UGAId": fields.Str(required=True, load_from="UGAId"),
        "UGAName": fields.Str(required=True, load_from="UGAName"),
        "UPathSet": fields.List(UPathSetSchema()),
    }


class PathXUGAInfoSchema(schema.ResponseSchema):
    """PathXUGAInfo - 加速实例配置信息"""

    fields = {
        "Domain": fields.Str(required=False, load_from="Domain"),
        "IPList": fields.List(fields.Str()),
        "UGAId": fields.Str(required=False, load_from="UGAId"),
    }


class UPathInfoSchema(schema.ResponseSchema):
    """UPathInfo - 加速线路信息"""

    fields = {
        "Bandwidth": fields.Int(required=False, load_from="Bandwidth"),
        "ChargeType": fields.Str(required=False, load_from="ChargeType"),
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "ExpireTime": fields.Int(required=False, load_from="ExpireTime"),
        "LineFromName": fields.Str(required=False, load_from="LineFromName"),
        "LineId": fields.Str(required=False, load_from="LineId"),
        "LineToName": fields.Str(required=False, load_from="LineToName"),
        "Name": fields.Str(required=False, load_from="Name"),
        "OutPublicIpList": fields.List(OutPublicIpInfoSchema()),
        "PostPaid": fields.Bool(required=False, load_from="PostPaid"),
        "UGAList": fields.List(PathXUGAInfoSchema()),
        "UPathId": fields.Str(required=False, load_from="UPathId"),
    }


class AlarmRulerSchema(schema.ResponseSchema):
    """AlarmRuler - 告警详情"""

    fields = {
        "AlarmFrequency": fields.Int(required=True, load_from="AlarmFrequency"),
        "AlarmStrategy": fields.Str(required=True, load_from="AlarmStrategy"),
        "AlarmTemplateRuleId": fields.Int(
            required=True, load_from="AlarmTemplateRuleId"
        ),
        "Compare": fields.Str(required=True, load_from="Compare"),
        "ContactGroupId": fields.Int(required=True, load_from="ContactGroupId"),
        "MetricName": fields.Str(required=True, load_from="MetricName"),
        "ResourceType": fields.Str(required=False, load_from="ResourceType"),
        "Threshold": fields.Int(required=True, load_from="Threshold"),
        "TriggerCount": fields.Int(required=True, load_from="TriggerCount"),
    }


class MatricPointSchema(schema.ResponseSchema):
    """MatricPoint - 某一时刻的监控数据"""

    fields = {
        "Timestamp": fields.Int(required=False, load_from="Timestamp"),
        "Value": fields.Int(required=False, load_from="Value"),
    }


class MetricPeriodSchema(schema.ResponseSchema):
    """MetricPeriod - 一段时间内的监控数据"""

    fields = {
        "NetworkIn": fields.List(MatricPointSchema()),
        "NetworkInUsage": fields.List(MatricPointSchema()),
        "NetworkOut": fields.List(MatricPointSchema()),
        "NetworkOutUsage": fields.List(MatricPointSchema()),
    }


class UGA3MetricSchema(schema.ResponseSchema):
    """UGA3Metric - 一段时间内的监控数据"""

    fields = {
        "ConnectCount": fields.List(MatricPointSchema()),
        "ConnectCountSubline": fields.List(MatricPointSchema()),
        "Delay": fields.List(MatricPointSchema()),
        "DelayPromote": fields.List(MatricPointSchema()),
        "DelayPromoteSubline": fields.List(MatricPointSchema()),
        "DelaySubline": fields.List(MatricPointSchema()),
        "NetworkIn": fields.List(MatricPointSchema()),
        "NetworkInSubline": fields.List(MatricPointSchema()),
        "NetworkInUsage": fields.List(MatricPointSchema()),
        "NetworkOut": fields.List(MatricPointSchema()),
        "NetworkOutSubline": fields.List(MatricPointSchema()),
        "NetworkOutUsage": fields.List(MatricPointSchema()),
    }


class UGA3PriceSchema(schema.ResponseSchema):
    """UGA3Price -"""

    fields = {
        "AccelerationArea": fields.Str(
            required=True, load_from="AccelerationArea"
        ),
        "AccelerationAreaName": fields.Str(
            required=True, load_from="AccelerationAreaName"
        ),
        "AccelerationBandwidthPrice": fields.Float(
            required=True, load_from="AccelerationBandwidthPrice"
        ),
        "AccelerationForwarderPrice": fields.Float(
            required=True, load_from="AccelerationForwarderPrice"
        ),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.ucdn.schemas import models

""" UCDN API Schema
"""


"""
API: AddCertificate

添加证书
"""


class AddCertificateRequestSchema(schema.RequestSchema):
    """AddCertificate - 添加证书"""

    fields = {
        "CaCert": fields.Str(required=False, dump_to="CaCert"),
        "CertName": fields.Str(required=True, dump_to="CertName"),
        "PrivateKey": fields.Str(required=True, dump_to="PrivateKey"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UserCert": fields.Str(required=True, dump_to="UserCert"),
    }


class AddCertificateResponseSchema(schema.ResponseSchema):
    """AddCertificate - 添加证书"""

    fields = {}


"""
API: BatchDescribeNewUcdnDomain

批量获取加速域名配置
"""


class BatchDescribeNewUcdnDomainRequestSchema(schema.RequestSchema):
    """BatchDescribeNewUcdnDomain - 批量获取加速域名配置"""

    fields = {
        "ChannelType": fields.Str(required=False, dump_to="ChannelType"),
        "DomainId": fields.List(fields.Str()),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class BatchDescribeNewUcdnDomainResponseSchema(schema.ResponseSchema):
    """BatchDescribeNewUcdnDomain - 批量获取加速域名配置"""

    fields = {
        "Arrearage": fields.List(
            fields.Str(), required=False, load_from="Arrearage"
        ),
        "ChargeType": fields.Int(required=False, load_from="ChargeType"),
        "DomainSet": fields.List(
            models.DomainInfoSchema(), required=False, load_from="DomainSet"
        ),
        "LastChargeType": fields.Int(
            required=False, load_from="LastChargeType"
        ),
        "MaxDomainNum": fields.Int(required=False, load_from="MaxDomainNum"),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
        "Vip": fields.Str(required=False, load_from="Vip"),
    }


"""
API: BatchRefreshNewUcdnDomainCache

批量刷新缓存
"""


class BatchRefreshNewUcdnDomainCacheRequestSchema(schema.RequestSchema):
    """BatchRefreshNewUcdnDomainCache - 批量刷新缓存"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Str(required=True, dump_to="Type"),
        "UrlList": fields.Str(required=True, dump_to="UrlList"),
    }


class BatchRefreshNewUcdnDomainCacheResponseSchema(schema.ResponseSchema):
    """BatchRefreshNewUcdnDomainCache - 批量刷新缓存"""

    fields = {
        "TaskId": fields.Str(required=False, load_from="TaskId"),
    }


"""
API: ControlUcdnDomainCacheAccess

封禁解封缓存访问
"""


class ControlUcdnDomainCacheAccessRequestSchema(schema.RequestSchema):
    """ControlUcdnDomainCacheAccess - 封禁解封缓存访问"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Str(required=True, dump_to="Type"),
        "UrlList": fields.List(fields.Str()),
    }


class ControlUcdnDomainCacheAccessResponseSchema(schema.ResponseSchema):
    """ControlUcdnDomainCacheAccess - 封禁解封缓存访问"""

    fields = {}


"""
API: DeleteCertificate

删除证书
"""


class DeleteCertificateRequestSchema(schema.RequestSchema):
    """DeleteCertificate - 删除证书"""

    fields = {
        "CertName": fields.Str(required=True, dump_to="CertName"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class DeleteCertificateResponseSchema(schema.ResponseSchema):
    """DeleteCertificate - 删除证书"""

    fields = {}


"""
API: DescribeNewUcdnPrefetchCacheTask

获取预取任务状态
"""


class DescribeNewUcdnPrefetchCacheTaskRequestSchema(schema.RequestSchema):
    """DescribeNewUcdnPrefetchCacheTask - 获取预取任务状态"""

    fields = {
        "BeginTime": fields.Int(required=False, dump_to="BeginTime"),
        "EndTime": fields.Int(required=False, dump_to="EndTime"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Status": fields.Str(required=False, dump_to="Status"),
        "TaskId": fields.List(fields.Str()),
    }


class DescribeNewUcdnPrefetchCacheTaskResponseSchema(schema.ResponseSchema):
    """DescribeNewUcdnPrefetchCacheTask - 获取预取任务状态"""

    fields = {
        "TaskList": fields.List(
            models.TaskInfoSchema(), required=False, load_from="TaskList"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeNewUcdnRefreshCacheTask

获取域名刷新任务状态
"""


class DescribeNewUcdnRefreshCacheTaskRequestSchema(schema.RequestSchema):
    """DescribeNewUcdnRefreshCacheTask - 获取域名刷新任务状态"""

    fields = {
        "BeginTime": fields.Int(required=False, dump_to="BeginTime"),
        "EndTime": fields.Int(required=False, dump_to="EndTime"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Status": fields.Str(required=False, dump_to="Status"),
        "TaskId": fields.List(fields.Str()),
    }


class DescribeNewUcdnRefreshCacheTaskResponseSchema(schema.ResponseSchema):
    """DescribeNewUcdnRefreshCacheTask - 获取域名刷新任务状态"""

    fields = {
        "TaskList": fields.List(
            models.TaskInfoSchema(), required=False, load_from="TaskList"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: GetCertificateV2

获取证书列表(新)
"""


class GetCertificateV2RequestSchema(schema.RequestSchema):
    """GetCertificateV2 - 获取证书列表(新)"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class GetCertificateV2ResponseSchema(schema.ResponseSchema):
    """GetCertificateV2 - 获取证书列表(新)"""

    fields = {
        "CertList": fields.List(
            models.CertListSchema(), required=True, load_from="CertList"
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: GetNewUcdnDomainBandwidth

获取域名带宽数据
"""


class GetNewUcdnDomainBandwidthRequestSchema(schema.RequestSchema):
    """GetNewUcdnDomainBandwidth - 获取域名带宽数据"""

    fields = {
        "Areacode": fields.Str(required=False, dump_to="Areacode"),
        "BeginTime": fields.Int(required=False, dump_to="BeginTime"),
        "DomainId": fields.List(fields.Str()),
        "EndTime": fields.Int(required=False, dump_to="EndTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Int(required=True, dump_to="Type"),
    }


class GetNewUcdnDomainBandwidthResponseSchema(schema.ResponseSchema):
    """GetNewUcdnDomainBandwidth - 获取域名带宽数据"""

    fields = {
        "BandwidthList": fields.List(
            models.BandwidthInfoSchema(),
            required=False,
            load_from="BandwidthList",
        ),
        "Traffic": fields.Float(required=False, load_from="Traffic"),
    }


"""
API: GetNewUcdnDomainHitRate

获取域名命中率
"""


class GetNewUcdnDomainHitRateRequestSchema(schema.RequestSchema):
    """GetNewUcdnDomainHitRate - 获取域名命中率"""

    fields = {
        "Areacode": fields.Str(required=False, dump_to="Areacode"),
        "BeginTime": fields.Int(required=False, dump_to="BeginTime"),
        "DomainId": fields.List(fields.Str()),
        "EndTime": fields.Int(required=False, dump_to="EndTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Int(required=False, dump_to="Type"),
    }


class GetNewUcdnDomainHitRateResponseSchema(schema.ResponseSchema):
    """GetNewUcdnDomainHitRate - 获取域名命中率"""

    fields = {
        "HitRateList": fields.List(
            models.HitRateInfoSchema(), required=False, load_from="HitRateList"
        ),
    }


"""
API: GetNewUcdnDomainHttpCode

获取域名状态码监控
"""


class GetNewUcdnDomainHttpCodeRequestSchema(schema.RequestSchema):
    """GetNewUcdnDomainHttpCode - 获取域名状态码监控"""

    fields = {
        "Areacode": fields.Str(required=False, dump_to="Areacode"),
        "BeginTime": fields.Int(required=False, dump_to="BeginTime"),
        "DomainId": fields.List(fields.Str()),
        "EndTime": fields.Int(required=False, dump_to="EndTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Int(required=True, dump_to="Type"),
    }


class GetNewUcdnDomainHttpCodeResponseSchema(schema.ResponseSchema):
    """GetNewUcdnDomainHttpCode - 获取域名状态码监控"""

    fields = {
        "HttpCodeDetail": fields.List(
            models.HttpCodeInfoSchema(),
            required=False,
            load_from="HttpCodeDetail",
        ),
    }


"""
API: GetNewUcdnDomainHttpCodeV2

获取域名详细状态码监控
"""


class GetNewUcdnDomainHttpCodeV2RequestSchema(schema.RequestSchema):
    """GetNewUcdnDomainHttpCodeV2 - 获取域名详细状态码监控"""

    fields = {
        "Areacode": fields.Str(required=False, dump_to="Areacode"),
        "BeginTime": fields.Int(required=True, dump_to="BeginTime"),
        "DomainId": fields.List(fields.Str()),
        "EndTime": fields.Int(required=True, dump_to="EndTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Int(required=True, dump_to="Type"),
    }


class GetNewUcdnDomainHttpCodeV2ResponseSchema(schema.ResponseSchema):
    """GetNewUcdnDomainHttpCodeV2 - 获取域名详细状态码监控"""

    fields = {
        "HttpCodeV2Detail": fields.List(
            models.HttpCodeV2DetailSchema(),
            required=False,
            load_from="HttpCodeV2Detail",
        ),
    }


"""
API: GetNewUcdnDomainRequestNum

获取域名请求数
"""


class GetNewUcdnDomainRequestNumRequestSchema(schema.RequestSchema):
    """GetNewUcdnDomainRequestNum - 获取域名请求数"""

    fields = {
        "Areacode": fields.Str(required=False, dump_to="Areacode"),
        "BeginTime": fields.Int(required=False, dump_to="BeginTime"),
        "DomainId": fields.List(fields.Str()),
        "EndTime": fields.Int(required=False, dump_to="EndTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Int(required=True, dump_to="Type"),
    }


class GetNewUcdnDomainRequestNumResponseSchema(schema.ResponseSchema):
    """GetNewUcdnDomainRequestNum - 获取域名请求数"""

    fields = {
        "RequestList": fields.List(
            models.RequestInfoSchema(), required=False, load_from="RequestList"
        ),
    }


"""
API: GetNewUcdnLogRefererStatistics

获取热点referer统计
"""


class GetNewUcdnLogRefererStatisticsRequestSchema(schema.RequestSchema):
    """GetNewUcdnLogRefererStatistics - 获取热点referer统计"""

    fields = {
        "Areacode": fields.Str(required=False, dump_to="Areacode"),
        "BeginTime": fields.Int(required=False, dump_to="BeginTime"),
        "DomainId": fields.Str(required=False, dump_to="DomainId"),
        "EndTime": fields.Int(required=False, dump_to="EndTime"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "OrderBy": fields.Int(required=False, dump_to="OrderBy"),
    }


class GetNewUcdnLogRefererStatisticsResponseSchema(schema.ResponseSchema):
    """GetNewUcdnLogRefererStatistics - 获取热点referer统计"""

    fields = {
        "RefererStatistics": fields.List(
            models.RefererStatisticsSchema(),
            required=False,
            load_from="RefererStatistics",
        ),
    }


"""
API: GetNewUcdnLogUrlStatistics

获取日志url统计
"""


class GetNewUcdnLogUrlStatisticsRequestSchema(schema.RequestSchema):
    """GetNewUcdnLogUrlStatistics - 获取日志url统计"""

    fields = {
        "Areacode": fields.Str(required=False, dump_to="Areacode"),
        "BeginTime": fields.Int(required=False, dump_to="BeginTime"),
        "DomainId": fields.Str(required=True, dump_to="DomainId"),
        "EndTime": fields.Int(required=False, dump_to="EndTime"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "OrderBy": fields.Int(required=False, dump_to="OrderBy"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class GetNewUcdnLogUrlStatisticsResponseSchema(schema.ResponseSchema):
    """GetNewUcdnLogUrlStatistics - 获取日志url统计"""

    fields = {
        "UrlStatisticsList": fields.List(
            models.UrlStatisticsSchema(),
            required=False,
            load_from="UrlStatisticsList",
        ),
    }


"""
API: GetUcdnDomain95BandwidthV2

获取域名九五峰值带宽数据
"""


class GetUcdnDomain95BandwidthV2RequestSchema(schema.RequestSchema):
    """GetUcdnDomain95BandwidthV2 - 获取域名九五峰值带宽数据"""

    fields = {
        "Areacode": fields.Str(required=False, dump_to="Areacode"),
        "BeginTime": fields.Int(required=True, dump_to="BeginTime"),
        "DomainId": fields.List(fields.Str()),
        "EndTime": fields.Int(required=True, dump_to="EndTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class GetUcdnDomain95BandwidthV2ResponseSchema(schema.ResponseSchema):
    """GetUcdnDomain95BandwidthV2 - 获取域名九五峰值带宽数据"""

    fields = {
        "CdnBandwidth": fields.Float(required=False, load_from="CdnBandwidth"),
        "Time": fields.Int(required=True, load_from="Time"),
    }


"""
API: GetUcdnDomainBandwidthV2

获取域名带宽数据(新)
"""


class GetUcdnDomainBandwidthV2RequestSchema(schema.RequestSchema):
    """GetUcdnDomainBandwidthV2 - 获取域名带宽数据(新)"""

    fields = {
        "Areacode": fields.Str(required=False, dump_to="Areacode"),
        "BeginTime": fields.Int(required=False, dump_to="BeginTime"),
        "DomainId": fields.List(fields.Str()),
        "EndTime": fields.Int(required=False, dump_to="EndTime"),
        "Primeval": fields.Int(required=False, dump_to="Primeval"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Protocol": fields.Str(required=False, dump_to="Protocol"),
        "Type": fields.Int(required=False, dump_to="Type"),
    }


class GetUcdnDomainBandwidthV2ResponseSchema(schema.ResponseSchema):
    """GetUcdnDomainBandwidthV2 - 获取域名带宽数据(新)"""

    fields = {
        "BandwidthTrafficList": fields.List(
            models.BandwidthTrafficInfoSchema(),
            required=False,
            load_from="BandwidthTrafficList",
        ),
    }


"""
API: GetUcdnDomainConfig

批量获取加速域名配置
"""


class GetUcdnDomainConfigRequestSchema(schema.RequestSchema):
    """GetUcdnDomainConfig - 批量获取加速域名配置"""

    fields = {
        "ChannelType": fields.Str(required=False, dump_to="ChannelType"),
        "DomainId": fields.List(fields.Str()),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class GetUcdnDomainConfigResponseSchema(schema.ResponseSchema):
    """GetUcdnDomainConfig - 批量获取加速域名配置"""

    fields = {
        "DomainList": fields.List(
            models.DomainConfigInfoSchema(),
            required=True,
            load_from="DomainList",
        ),
    }


"""
API: GetUcdnDomainHitRate

获取域名命中率
"""


class GetUcdnDomainHitRateRequestSchema(schema.RequestSchema):
    """GetUcdnDomainHitRate - 获取域名命中率"""

    fields = {
        "Areacode": fields.Str(required=False, dump_to="Areacode"),
        "BeginTime": fields.Int(required=False, dump_to="BeginTime"),
        "DomainId": fields.List(fields.Str()),
        "EndTime": fields.Int(required=False, dump_to="EndTime"),
        "HitType": fields.Int(required=False, dump_to="HitType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Int(required=True, dump_to="Type"),
    }


class GetUcdnDomainHitRateResponseSchema(schema.ResponseSchema):
    """GetUcdnDomainHitRate - 获取域名命中率"""

    fields = {
        "HitRateList": fields.List(
            models.HitRateInfoV2Schema(),
            required=False,
            load_from="HitRateList",
        ),
    }


"""
API: GetUcdnDomainHttpCodeV2

获取域名状态码信息
"""


class GetUcdnDomainHttpCodeV2RequestSchema(schema.RequestSchema):
    """GetUcdnDomainHttpCodeV2 - 获取域名状态码信息"""

    fields = {
        "Areacode": fields.Str(required=False, dump_to="Areacode"),
        "BeginTime": fields.Int(required=False, dump_to="BeginTime"),
        "DomainId": fields.List(fields.Str()),
        "EndTime": fields.Int(required=False, dump_to="EndTime"),
        "Layer": fields.Str(required=False, dump_to="Layer"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Int(required=True, dump_to="Type"),
    }


class GetUcdnDomainHttpCodeV2ResponseSchema(schema.ResponseSchema):
    """GetUcdnDomainHttpCodeV2 - 获取域名状态码信息"""

    fields = {
        "HttpCodeDetail": fields.List(
            models.HttpCodeInfoV2Schema(),
            required=False,
            load_from="HttpCodeDetail",
        ),
    }


"""
API: GetUcdnDomainInfoList

获取域名基本信息
"""


class GetUcdnDomainInfoListRequestSchema(schema.RequestSchema):
    """GetUcdnDomainInfoList - 获取域名基本信息"""

    fields = {
        "PageIndex": fields.Int(required=False, dump_to="PageIndex"),
        "PageSize": fields.Int(required=False, dump_to="PageSize"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class GetUcdnDomainInfoListResponseSchema(schema.ResponseSchema):
    """GetUcdnDomainInfoList - 获取域名基本信息"""

    fields = {
        "DomainInfoList": fields.List(
            models.DomainBaseInfoSchema(),
            required=True,
            load_from="DomainInfoList",
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: GetUcdnDomainLog

获取加速域名原始日志
"""


class GetUcdnDomainLogRequestSchema(schema.RequestSchema):
    """GetUcdnDomainLog - 获取加速域名原始日志"""

    fields = {
        "BeginTime": fields.Int(required=False, dump_to="BeginTime"),
        "DomainId": fields.List(fields.Str()),
        "EndTime": fields.Int(required=False, dump_to="EndTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Int(required=False, dump_to="Type"),
    }


class GetUcdnDomainLogResponseSchema(schema.ResponseSchema):
    """GetUcdnDomainLog - 获取加速域名原始日志"""

    fields = {
        "LogSet": fields.List(
            models.LogSetListSchema(), required=False, load_from="LogSet"
        ),
    }


"""
API: GetUcdnDomainLogV2

获取域名5分钟日志
"""


class GetUcdnDomainLogV2RequestSchema(schema.RequestSchema):
    """GetUcdnDomainLogV2 - 获取域名5分钟日志"""

    fields = {
        "BeginTime": fields.Int(required=True, dump_to="BeginTime"),
        "DomainId": fields.List(fields.Str()),
        "EndTime": fields.Int(required=True, dump_to="EndTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class GetUcdnDomainLogV2ResponseSchema(schema.ResponseSchema):
    """GetUcdnDomainLogV2 - 获取域名5分钟日志"""

    fields = {
        "DomainLogSet": fields.List(
            models.DomanLogListSchema(), required=True, load_from="DomainLogSet"
        ),
    }


"""
API: GetUcdnDomainOriginHttpCode

获取域名源站状态码监控
"""


class GetUcdnDomainOriginHttpCodeRequestSchema(schema.RequestSchema):
    """GetUcdnDomainOriginHttpCode - 获取域名源站状态码监控"""

    fields = {
        "Areacode": fields.Str(required=False, dump_to="Areacode"),
        "BeginTime": fields.Int(required=False, dump_to="BeginTime"),
        "DomainId": fields.List(fields.Str()),
        "EndTime": fields.Int(required=False, dump_to="EndTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Int(required=True, dump_to="Type"),
    }


class GetUcdnDomainOriginHttpCodeResponseSchema(schema.ResponseSchema):
    """GetUcdnDomainOriginHttpCode - 获取域名源站状态码监控"""

    fields = {
        "HttpCodeDetail": fields.List(
            models.HttpCodeInfoSchema(),
            required=False,
            load_from="HttpCodeDetail",
        ),
    }


"""
API: GetUcdnDomainOriginHttpCodeDetail

获取域名源站详细状态码监控
"""


class GetUcdnDomainOriginHttpCodeDetailRequestSchema(schema.RequestSchema):
    """GetUcdnDomainOriginHttpCodeDetail - 获取域名源站详细状态码监控"""

    fields = {
        "Areacode": fields.Str(required=False, dump_to="Areacode"),
        "BeginTime": fields.Int(required=True, dump_to="BeginTime"),
        "DomainId": fields.List(fields.Str()),
        "EndTime": fields.Int(required=True, dump_to="EndTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Int(required=True, dump_to="Type"),
    }


class GetUcdnDomainOriginHttpCodeDetailResponseSchema(schema.ResponseSchema):
    """GetUcdnDomainOriginHttpCodeDetail - 获取域名源站详细状态码监控"""

    fields = {
        "HttpCodeV2Detail": fields.List(
            models.HttpCodeV2DetailSchema(),
            required=False,
            load_from="HttpCodeV2Detail",
        ),
    }


"""
API: GetUcdnDomainOriginRequestNum

获取域名回源请求数
"""


class GetUcdnDomainOriginRequestNumRequestSchema(schema.RequestSchema):
    """GetUcdnDomainOriginRequestNum - 获取域名回源请求数"""

    fields = {
        "Areacode": fields.Str(required=False, dump_to="Areacode"),
        "BeginTime": fields.Int(required=True, dump_to="BeginTime"),
        "DomainId": fields.List(fields.Str()),
        "EndTime": fields.Int(required=True, dump_to="EndTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Int(required=True, dump_to="Type"),
    }


class GetUcdnDomainOriginRequestNumResponseSchema(schema.ResponseSchema):
    """GetUcdnDomainOriginRequestNum - 获取域名回源请求数"""

    fields = {
        "RequestList": fields.List(
            models.RequestInfoV2Schema(),
            required=False,
            load_from="RequestList",
        ),
    }


"""
API: GetUcdnDomainPrefetchEnable

获取域名预取开启状态
"""


class GetUcdnDomainPrefetchEnableRequestSchema(schema.RequestSchema):
    """GetUcdnDomainPrefetchEnable - 获取域名预取开启状态"""

    fields = {
        "DomainId": fields.Str(required=True, dump_to="DomainId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class GetUcdnDomainPrefetchEnableResponseSchema(schema.ResponseSchema):
    """GetUcdnDomainPrefetchEnable - 获取域名预取开启状态"""

    fields = {
        "Enable": fields.Int(required=False, load_from="Enable"),
    }


"""
API: GetUcdnDomainRequestNumV2

获取域名请求数
"""


class GetUcdnDomainRequestNumV2RequestSchema(schema.RequestSchema):
    """GetUcdnDomainRequestNumV2 - 获取域名请求数"""

    fields = {
        "Areacode": fields.Str(required=False, dump_to="Areacode"),
        "BeginTime": fields.Int(required=True, dump_to="BeginTime"),
        "DomainId": fields.List(fields.Str()),
        "EndTime": fields.Int(required=True, dump_to="EndTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Int(required=True, dump_to="Type"),
    }


class GetUcdnDomainRequestNumV2ResponseSchema(schema.ResponseSchema):
    """GetUcdnDomainRequestNumV2 - 获取域名请求数"""

    fields = {
        "RequestList": fields.List(
            models.RequestInfoSchema(), required=False, load_from="RequestList"
        ),
    }


"""
API: GetUcdnDomainRequestNumV3

获取域名请求数
"""


class GetUcdnDomainRequestNumV3RequestSchema(schema.RequestSchema):
    """GetUcdnDomainRequestNumV3 - 获取域名请求数"""

    fields = {
        "Areacode": fields.Str(required=False, dump_to="Areacode"),
        "BeginTime": fields.Int(required=True, dump_to="BeginTime"),
        "DomainId": fields.List(fields.Str()),
        "EndTime": fields.Int(required=True, dump_to="EndTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Protocol": fields.Str(required=False, dump_to="Protocol"),
        "Type": fields.Int(required=True, dump_to="Type"),
    }


class GetUcdnDomainRequestNumV3ResponseSchema(schema.ResponseSchema):
    """GetUcdnDomainRequestNumV3 - 获取域名请求数"""

    fields = {
        "RequestList": fields.List(
            models.RequestInfoV2Schema(),
            required=False,
            load_from="RequestList",
        ),
    }


"""
API: GetUcdnDomainTraffic

获取加速域名流量使用信息
"""


class GetUcdnDomainTrafficRequestSchema(schema.RequestSchema):
    """GetUcdnDomainTraffic - 获取加速域名流量使用信息"""

    fields = {
        "AccountType": fields.Str(required=False, dump_to="AccountType"),
        "Areacode": fields.Str(required=False, dump_to="Areacode"),
        "BeginTime": fields.Int(required=False, dump_to="BeginTime"),
        "DomainId": fields.List(fields.Str()),
        "EndTime": fields.Int(required=False, dump_to="EndTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class GetUcdnDomainTrafficResponseSchema(schema.ResponseSchema):
    """GetUcdnDomainTraffic - 获取加速域名流量使用信息"""

    fields = {
        "TrafficSet": fields.List(
            models.UcdnDomainTrafficSetSchema(),
            required=False,
            load_from="TrafficSet",
        ),
    }


"""
API: GetUcdnPassBandwidth

获取回源带宽数据（cdn回客户源站部分）
"""


class GetUcdnPassBandwidthRequestSchema(schema.RequestSchema):
    """GetUcdnPassBandwidth - 获取回源带宽数据（cdn回客户源站部分）"""

    fields = {
        "Areacode": fields.Str(required=False, dump_to="Areacode"),
        "BeginTime": fields.Int(required=False, dump_to="BeginTime"),
        "DomainId": fields.List(fields.Str()),
        "EndTime": fields.Int(required=False, dump_to="EndTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Int(required=True, dump_to="Type"),
    }


class GetUcdnPassBandwidthResponseSchema(schema.ResponseSchema):
    """GetUcdnPassBandwidth - 获取回源带宽数据（cdn回客户源站部分）"""

    fields = {
        "BandwidthDetail": fields.List(
            models.BandwidthInfoDetailSchema(),
            required=False,
            load_from="BandwidthDetail",
        ),
    }


"""
API: GetUcdnPassBandwidthV2

获取回源带宽数据（cdn回客户源站部分）
"""


class GetUcdnPassBandwidthV2RequestSchema(schema.RequestSchema):
    """GetUcdnPassBandwidthV2 - 获取回源带宽数据（cdn回客户源站部分）"""

    fields = {
        "Areacode": fields.Str(required=False, dump_to="Areacode"),
        "BeginTime": fields.Int(required=False, dump_to="BeginTime"),
        "DomainId": fields.List(fields.Str()),
        "EndTime": fields.Int(required=False, dump_to="EndTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Int(required=True, dump_to="Type"),
    }


class GetUcdnPassBandwidthV2ResponseSchema(schema.ResponseSchema):
    """GetUcdnPassBandwidthV2 - 获取回源带宽数据（cdn回客户源站部分）"""

    fields = {
        "BandwidthList": fields.List(
            models.BandwidthInfoDetailSchema(),
            required=False,
            load_from="BandwidthList",
        ),
    }


"""
API: GetUcdnProIspBandwidthV2

按省份运营商获取域名带宽数据
"""


class GetUcdnProIspBandwidthV2RequestSchema(schema.RequestSchema):
    """GetUcdnProIspBandwidthV2 - 按省份运营商获取域名带宽数据"""

    fields = {
        "BeginTime": fields.Int(required=True, dump_to="BeginTime"),
        "DomainId": fields.List(fields.Str()),
        "EndTime": fields.Int(required=True, dump_to="EndTime"),
        "Isp": fields.Str(required=False, dump_to="Isp"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Province": fields.List(fields.Str()),
        "Type": fields.Int(required=True, dump_to="Type"),
    }


class GetUcdnProIspBandwidthV2ResponseSchema(schema.ResponseSchema):
    """GetUcdnProIspBandwidthV2 - 按省份运营商获取域名带宽数据"""

    fields = {
        "BandwidthSet": fields.List(
            models.ProIspBandwidthSetSchema(),
            required=True,
            load_from="BandwidthSet",
        ),
    }


"""
API: GetUcdnProIspRequestNumV2

按省份运营商获取域名请求数
"""


class GetUcdnProIspRequestNumV2RequestSchema(schema.RequestSchema):
    """GetUcdnProIspRequestNumV2 - 按省份运营商获取域名请求数"""

    fields = {
        "BeginTime": fields.Int(required=True, dump_to="BeginTime"),
        "DomainId": fields.List(fields.Str()),
        "EndTime": fields.Int(required=True, dump_to="EndTime"),
        "Isp": fields.Str(required=False, dump_to="Isp"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Province": fields.List(fields.Str()),
        "Type": fields.Int(required=False, dump_to="Type"),
    }


class GetUcdnProIspRequestNumV2ResponseSchema(schema.ResponseSchema):
    """GetUcdnProIspRequestNumV2 - 按省份运营商获取域名请求数"""

    fields = {
        "RequestNumSet": fields.List(
            models.ProIspRequestNumSetV2Schema(),
            required=True,
            load_from="RequestNumSet",
        ),
    }


"""
API: GetUcdnTraffic

获取流量信息
"""


class GetUcdnTrafficRequestSchema(schema.RequestSchema):
    """GetUcdnTraffic - 获取流量信息"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class GetUcdnTrafficResponseSchema(schema.ResponseSchema):
    """GetUcdnTraffic - 获取流量信息"""

    fields = {
        "TrafficSet": fields.List(
            models.TrafficSetSchema(), required=False, load_from="TrafficSet"
        ),
    }


"""
API: GetUcdnTrafficV2

获取流量信息
"""


class GetUcdnTrafficV2RequestSchema(schema.RequestSchema):
    """GetUcdnTrafficV2 - 获取流量信息"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class GetUcdnTrafficV2ResponseSchema(schema.ResponseSchema):
    """GetUcdnTrafficV2 - 获取流量信息"""

    fields = {
        "TrafficSet": fields.List(
            models.TrafficSetSchema(), required=False, load_from="TrafficSet"
        ),
    }


"""
API: PrefetchNewUcdnDomainCache

提交预取任务
"""


class PrefetchNewUcdnDomainCacheRequestSchema(schema.RequestSchema):
    """PrefetchNewUcdnDomainCache - 提交预取任务"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "UrlList": fields.List(fields.Str()),
    }


class PrefetchNewUcdnDomainCacheResponseSchema(schema.ResponseSchema):
    """PrefetchNewUcdnDomainCache - 提交预取任务"""

    fields = {
        "TaskId": fields.Str(required=False, load_from="TaskId"),
    }


"""
API: QueryIpLocation

查询IP信息
"""


class QueryIpLocationRequestSchema(schema.RequestSchema):
    """QueryIpLocation - 查询IP信息"""

    fields = {
        "Ip": fields.List(fields.Str()),
    }


class QueryIpLocationResponseSchema(schema.ResponseSchema):
    """QueryIpLocation - 查询IP信息"""

    fields = {
        "Data": fields.List(
            models.IpLocationInfoSchema(), required=True, load_from="Data"
        ),
    }


"""
API: RefreshNewUcdnDomainCache

刷新缓存
"""


class RefreshNewUcdnDomainCacheRequestSchema(schema.RequestSchema):
    """RefreshNewUcdnDomainCache - 刷新缓存"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Str(required=True, dump_to="Type"),
        "UrlList": fields.List(fields.Str()),
    }


class RefreshNewUcdnDomainCacheResponseSchema(schema.ResponseSchema):
    """RefreshNewUcdnDomainCache - 刷新缓存"""

    fields = {
        "TaskId": fields.Str(required=False, load_from="TaskId"),
    }


"""
API: SwitchUcdnChargeType

切换账号计费方式
"""


class SwitchUcdnChargeTypeRequestSchema(schema.RequestSchema):
    """SwitchUcdnChargeType - 切换账号计费方式"""

    fields = {
        "ChargeType": fields.Str(required=True, dump_to="ChargeType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class SwitchUcdnChargeTypeResponseSchema(schema.ResponseSchema):
    """SwitchUcdnChargeType - 切换账号计费方式"""

    fields = {}



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

import typing


from ucloud.core.client import Client
from ucloud.services.ugn.schemas import apis


class UGNClient(Client):
    def __init__(
        self, config: dict, transport=None, middleware=None, logger=None
    ):
        super(UGNClient, self).__init__(config, transport, middleware, logger)

    def attach_ugn_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """AttachUGNInstance - 实例加入云联网

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **InstanceId** (str) - (Required) 实例Id
        - **InstanceProjectId** (str) - (Required) 实例归属ProjectId
        - **InstanceRegion** (str) - (Required) 实例归属地域
        - **InstanceType** (str) - (Required) 实例类型
        - **UGNId** (str) - (Required) 云联网Id

        **Response**

        - **Message** (str) - 返回码描述信息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.AttachUGNInstanceRequestSchema().dumps(d)

        resp = self.invoke("AttachUGNInstance", d, **kwargs)
        return apis.AttachUGNInstanceResponseSchema().loads(resp)

    def batch_detach_ugn_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """BatchDetachUGNInstance - 批量移除云联网中实例

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **InstanceIds** (list) - (Required) 实例id
        - **UGNId** (str) - (Required) 云联网id

        **Response**

        - **InstanceIds** (list) - 删除成功的实例id

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.BatchDetachUGNInstanceRequestSchema().dumps(d)

        resp = self.invoke("BatchDetachUGNInstance", d, **kwargs)
        return apis.BatchDetachUGNInstanceResponseSchema().loads(resp)

    def create_inter_region_bandwidth(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """CreateInterRegionBandwidth - 购买跨域带宽

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Bandwidth** (int) - (Required) 带宽（单位为Mb/s）
        - **ChargeType** (str) - (Required) 计费类型
        - **PayMode** (str) - (Required) 付费类型
        - **Quantity** (int) - (Required) 购买时长
        - **Region0** (str) - (Required) 跨域带宽归属地域
        - **Region1** (str) - (Required) 跨域带宽归属地域
        - **UGNId** (str) - (Required) 云联网Id
        - **CouponId** (str) - 代金券Id

        **Response**

        - **InterRegionBandwidthId** (str) - 跨域带宽Id
        - **Message** (str) - 返回码描述信息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.CreateInterRegionBandwidthRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateInterRegionBandwidth", d, **kwargs)
        return apis.CreateInterRegionBandwidthResponseSchema().loads(resp)

    def create_ugn(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
        """CreateUGN - 创建云联网

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Name** (str) - 云联网名称，如果没有传入，默认值为“UGN”
        - **Remark** (str) - 云联网备注，如果没有传入的话，默认为“”
        - **Tag** (str) - 业务组Id，如果没有传入，默认值为“Default”

        **Response**

        - **Message** (str) - 返回码描述信息
        - **UGNId** (str) - 云联网Id

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.CreateUGNRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("CreateUGN", d, **kwargs)
        return apis.CreateUGNResponseSchema().loads(resp)

    def delete_inter_region_bandwidth(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DeleteInterRegionBandwidth - 删除跨域带宽

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **InterRegionBandwidthId** (str) - (Required) 跨域带宽Id
        - **UGNId** (str) - (Required) 云联网Id

        **Response**

        - **Message** (str) - 返回码描述信息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DeleteInterRegionBandwidthRequestSchema().dumps(d)

        resp = self.invoke("DeleteInterRegionBandwidth", d, **kwargs)
        return apis.DeleteInterRegionBandwidthResponseSchema().loads(resp)

    def delete_ugn(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
        """DeleteUGN - 删除云联网

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **UGNId** (str) - (Required) 云联网Id

        **Response**

        - **Message** (str) - 返回码描述信息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DeleteUGNRequestSchema().dumps(d)

        resp = self.invoke("DeleteUGN", d, **kwargs)
        return apis.DeleteUGNResponseSchema().loads(resp)

    def describe_inter_region_bandwidth(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeInterRegionBandwidth - 查询跨域带宽

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **UGNId** (str) - (Required) 云联网Id
        - **InterRegionBandwidthIds** (list) - 跨域带宽Id
        - **Limit** (int) - 数据分页值。默认为20
        - **Offset** (int) - 数据偏移量。默认为0

        **Response**

        - **InterRegionBandwidths** (list) - 见 **InterRegionBandwidth** 模型定义
        - **Message** (str) - 返回码描述信息
        - **TotalCount** (int) - InterRegionBandwidths字段的数量

        **Response Model**

        **InterRegionBandwidth**
        - **Bandwidth** (int) - 带宽（单位为Mb/s）
        - **ChargeType** (str) - 计费类型
        - **CreateTime** (int) - 创建时间
        - **ExpireTime** (int) - 到期时间
        - **InterRegionBandwidthId** (str) - 跨域带宽Id
        - **PayMode** (str) - 付费类型
        - **Region0** (str) - 跨域带宽地域
        - **Region1** (str) - 跨域带宽地域
        - **State** (int) - 跨域带宽状态
        - **UGNId** (str) - 云联网Id


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DescribeInterRegionBandwidthRequestSchema().dumps(d)

        resp = self.invoke("DescribeInterRegionBandwidth", d, **kwargs)
        return apis.DescribeInterRegionBandwidthResponseSchema().loads(resp)

    def describe_ugn(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
        """DescribeUGN - 查询云联网

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Limit** (int) - 数据分页值。默认为20
        - **Offset** (int) - 数据偏移量。默认为0
        - **UGNIds** (list) - 云联网Id

        **Response**

        - **Message** (str) - 返回码描述信息
        - **TotalCount** (int) - UGNs字段的数量
        - **UGNs** (list) - 见 **UGN** 模型定义

        **Response Model**

        **UGN**
        - **CreateTime** (int) - 云联网创建时间
        - **Instances** (list) - 实例Id
        - **InterRegionBandwidths** (list) - 跨域路由Id
        - **Name** (str) - 云联网名称
        - **Remark** (str) - 云联网备注
        - **RouteRules** (list) - 路由规则Id
        - **Tag** (str) - 业务组Id
        - **UGNId** (str) - 云联网Id


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DescribeUGNRequestSchema().dumps(d)

        resp = self.invoke("DescribeUGN", d, **kwargs)
        return apis.DescribeUGNResponseSchema().loads(resp)

    def describe_ugn_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeUGNInstance - 查询云联网实例

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **UGNId** (str) - (Required) 云联网Id
        - **InstanceIds** (list) - 实例Id
        - **Limit** (int) - 数据分页值。默认为20
        - **Offset** (int) - 数据偏移量。默认为0

        **Response**

        - **Message** (str) - 返回码描述信息
        - **TotalCount** (int) - UGNInstances字段的数量
        - **UGNInstances** (list) - 见 **Instance** 模型定义

        **Response Model**

        **Instance**
        - **CreateTime** (int) - 加入时间
        - **InstanceId** (str) - 实例Id
        - **InstanceOrganizationName** (str) - 实例归属项目名称
        - **InstanceProjectId** (str) - 实例归属ProjectId
        - **InstanceRegion** (str) - 实例归属地域
        - **InstanceType** (str) - 实例类型
        - **Networks** (list) - 网段信息
        - **State** (int) - 实例状态
        - **UGNId** (str) - 云联网Id


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DescribeUGNInstanceRequestSchema().dumps(d)

        resp = self.invoke("DescribeUGNInstance", d, **kwargs)
        return apis.DescribeUGNInstanceResponseSchema().loads(resp)

    def describe_ugn_region_list(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeUGNRegionList - 获取ugn支持的地域

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_

        **Response**

        - **Message** (str) - 返回码描述信息
        - **RegionList** (list) - 地域列表

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DescribeUGNRegionListRequestSchema().dumps(d)

        resp = self.invoke("DescribeUGNRegionList", d, **kwargs)
        return apis.DescribeUGNRegionListResponseSchema().loads(resp)

    def describe_ugn_route_rule(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DescribeUGNRouteRule - 查询路由规则

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **UGNId** (str) - (Required) 云联网Id
        - **Limit** (int) - 数据分页值。默认为20
        - **Offset** (int) - 数据偏移量。默认为0
        - **RouteRuleIds** (list) - 路由规则Id

        **Response**

        - **Message** (str) - 返回码描述信息
        - **TotalCount** (int) - UGNRouteRules字段的数量
        - **UGNRouteRules** (list) - 见 **RouteRule** 模型定义

        **Response Model**

        **RouteRule**
        - **CreateTime** (int) - 创建时间
        - **DeriveInstanceId** (str) - 归属实例Id
        - **DeriveInstanceRegion** (str) - 归属实例地域
        - **DeriveInstanceType** (str) - 归属实例类型
        - **DeriveRouteRuleId** (str) - 归属实例路由规则Id
        - **DeriveRouteTableId** (str) - 归属实例路由表Id
        - **DstAddr** (str) - 目的地址
        - **Enable** (bool) - false:未使能true:已使能
        - **NextHopId** (str) - 归属实例路由下一跳
        - **NextHopType** (str) - 归属实例路由下一跳类型
        - **Priority** (int) - 优先级
        - **Rollback** (bool) - false:不可撤回true:可撤回
        - **RouteRuleId** (str) - 路由规则Id
        - **RouteRuleType** (int) - 路由规则类型，枚举值 0：自动发布的LOCAL和动态路由1：手动发布的自定义路由


        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DescribeUGNRouteRuleRequestSchema().dumps(d)

        resp = self.invoke("DescribeUGNRouteRule", d, **kwargs)
        return apis.DescribeUGNRouteRuleResponseSchema().loads(resp)

    def detach_ugn_instance(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """DetachUGNInstance - 实例退出云联网

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **InstanceId** (str) - (Required) 实例Id
        - **InstanceType** (str) - (Required) 实例类型
        - **UGNId** (str) - (Required) 云联网Id

        **Response**

        - **Message** (str) - 返回码描述信息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.DetachUGNInstanceRequestSchema().dumps(d)

        resp = self.invoke("DetachUGNInstance", d, **kwargs)
        return apis.DetachUGNInstanceResponseSchema().loads(resp)

    def modify_inter_region_bandwidth(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ModifyInterRegionBandwidth - 修改跨域带宽

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **Bandwidth** (str) - (Required) 带宽（单位为Mb/s）
        - **InterRegionBandwidthId** (str) - (Required) 跨域带宽Id
        - **UGNId** (str) - (Required) 云联网Id
        - **PayMode** (str) - 付费类型

        **Response**

        - **Message** (str) - 返回码描述信息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.ModifyInterRegionBandwidthRequestSchema().dumps(d)

        resp = self.invoke("ModifyInterRegionBandwidth", d, **kwargs)
        return apis.ModifyInterRegionBandwidthResponseSchema().loads(resp)

    def modify_ugn_attribute(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """ModifyUGNAttribute - 修改云联网属性

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **UGNId** (str) - (Required) 云联网Id
        - **Name** (str) - 云联网名称
        - **Remark** (str) - 云联网备注

        **Response**

        - **Message** (str) - 错误码描述信息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.ModifyUGNAttributeRequestSchema().dumps(d)

        resp = self.invoke("ModifyUGNAttribute", d, **kwargs)
        return apis.ModifyUGNAttributeResponseSchema().loads(resp)

    def publish_ugn_route_rule(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """PublishUGNRouteRule - 发布云联网路由规则

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **DeriveRouteRuleId** (str) - (Required) 归属实例路由规则Id
        - **DeriveRouteTableId** (str) - (Required) 归属实例路由表Id
        - **InstanceId** (str) - (Required) 实例Id
        - **UGNId** (str) - (Required) 云联网Id

        **Response**

        - **Message** (str) - 返回码描述信息
        - **RouteRuleId** (str) - 路由规则Id

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.PublishUGNRouteRuleRequestSchema().dumps(d)

        # build options
        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent

        resp = self.invoke("PublishUGNRouteRule", d, **kwargs)
        return apis.PublishUGNRouteRuleResponseSchema().loads(resp)

    def unpublish_ugn_route_rule(
        self, req: typing.Optional[dict] = None, **kwargs
    ) -> dict:
        """UnpublishUGNRouteRule - 取消发布云联网路由规则

        **Request**

        - **ProjectId** (str) - (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考 `GetProjectList接口 <https://docs.ucloud.cn/api/summary/get_project_list>`_
        - **DeriveRouteRuleId** (str) - (Required) 归属实例路由规则Id
        - **DeriveRouteTableId** (str) - (Required) 归属实例路由表Id
        - **InstanceId** (str) - (Required) 实例Id
        - **UGNId** (str) - (Required) 云联网Id

        **Response**

        - **Message** (str) - 返回码描述信息

        """
        # build request
        d = {
            "ProjectId": self.config.project_id,
        }
        req and d.update(req)
        d = apis.UnpublishUGNRouteRuleRequestSchema().dumps(d)

        resp = self.invoke("UnpublishUGNRouteRule", d, **kwargs)
        return apis.UnpublishUGNRouteRuleResponseSchema().loads(resp)



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core.typesystem import schema, fields


class UPhoneInstanceSchema(schema.ResponseSchema):
    """UPhoneInstance -"""

    fields = {
        "CPU": fields.Int(required=True, load_from="CPU"),
        "Callback": fields.Str(required=True, load_from="Callback"),
        "ChargeType": fields.Str(required=False, load_from="ChargeType"),
        "CityId": fields.Str(required=True, load_from="CityId"),
        "CityName": fields.Str(required=True, load_from="CityName"),
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "DiskSize": fields.Int(required=True, load_from="DiskSize"),
        "ExpireTime": fields.Int(required=False, load_from="ExpireTime"),
        "ImageId": fields.Str(required=True, load_from="ImageId"),
        "Ip": fields.Str(required=False, load_from="Ip"),
        "IpRegion": fields.Str(required=False, load_from="IpRegion"),
        "Memory": fields.Int(required=True, load_from="Memory"),
        "OsType": fields.Str(required=True, load_from="OsType"),
        "Refresh": fields.Int(required=True, load_from="Refresh"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "Resolution": fields.Str(required=True, load_from="Resolution"),
        "ServerId": fields.Str(required=True, load_from="ServerId"),
        "SplashScreen": fields.Str(required=True, load_from="SplashScreen"),
        "State": fields.Str(required=True, load_from="State"),
        "Tag": fields.Str(required=True, load_from="Tag"),
        "UPhoneId": fields.Str(required=True, load_from="UPhoneId"),
        "UPhoneModelName": fields.Str(
            required=True, load_from="UPhoneModelName"
        ),
        "UPhoneName": fields.Str(required=True, load_from="UPhoneName"),
    }


class AppInstanceSchema(schema.ResponseSchema):
    """AppInstance -"""

    fields = {
        "AppId": fields.Str(required=True, load_from="AppId"),
        "AppName": fields.Str(required=True, load_from="AppName"),
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "Description": fields.Str(required=False, load_from="Description"),
        "ModifyTime": fields.Int(required=True, load_from="ModifyTime"),
    }


class AppVersionInstanceSchema(schema.ResponseSchema):
    """AppVersionInstance -"""

    fields = {
        "AppId": fields.Str(required=True, load_from="AppId"),
        "AppVersionId": fields.Str(required=True, load_from="AppVersionId"),
        "AppVersionName": fields.Str(required=True, load_from="AppVersionName"),
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "Description": fields.Str(required=False, load_from="Description"),
        "ModifyTime": fields.Int(required=True, load_from="ModifyTime"),
        "PackageName": fields.Str(required=True, load_from="PackageName"),
        "URL": fields.Str(required=True, load_from="URL"),
    }


class CityInstanceSchema(schema.ResponseSchema):
    """CityInstance -"""

    fields = {
        "CityAlias": fields.Str(required=False, load_from="CityAlias"),
        "CityId": fields.Str(required=False, load_from="CityId"),
        "CityName": fields.Str(required=False, load_from="CityName"),
        "CityType": fields.Str(required=False, load_from="CityType"),
        "IsSoldOut": fields.Bool(required=False, load_from="IsSoldOut"),
    }


class UPhoneDetailInstanceSchema(schema.ResponseSchema):
    """UPhoneDetailInstance -"""

    fields = {
        "AppVersion": AppVersionInstanceSchema(),
        "CPU": fields.Int(required=False, load_from="CPU"),
        "CityId": fields.Str(required=False, load_from="CityId"),
        "CityName": fields.Str(required=False, load_from="CityName"),
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "DiskSize": fields.Int(required=False, load_from="DiskSize"),
        "ImageId": fields.Str(required=False, load_from="ImageId"),
        "Memory": fields.Int(required=False, load_from="Memory"),
        "OsType": fields.Str(required=False, load_from="OsType"),
        "Refresh": fields.Int(required=False, load_from="Refresh"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "Resolution": fields.Str(required=False, load_from="Resolution"),
        "ServerId": fields.Str(required=False, load_from="ServerId"),
        "State": fields.Str(required=False, load_from="State"),
        "UPhoneId": fields.Str(required=False, load_from="UPhoneId"),
        "UPhoneModelName": fields.Str(
            required=False, load_from="UPhoneModelName"
        ),
        "UPhoneName": fields.Str(required=False, load_from="UPhoneName"),
    }


class UPhoneImageInstanceSchema(schema.ResponseSchema):
    """UPhoneImageInstance -"""

    fields = {
        "AppVersions": fields.List(AppVersionInstanceSchema()),
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "Description": fields.Str(required=False, load_from="Description"),
        "ImageId": fields.Str(required=True, load_from="ImageId"),
        "ImageName": fields.Str(required=True, load_from="ImageName"),
        "ImageState": fields.Str(required=True, load_from="ImageState"),
        "ImageType": fields.Str(required=True, load_from="ImageType"),
        "ModifyTime": fields.Int(required=True, load_from="ModifyTime"),
        "OsType": fields.Str(required=True, load_from="OsType"),
        "UPhoneId": fields.Str(required=False, load_from="UPhoneId"),
    }


class IpRegionSchema(schema.ResponseSchema):
    """IpRegion - 独立IP地域信息"""

    fields = {
        "Id": fields.Str(required=True, load_from="Id"),
        "StockStatus": fields.Str(required=True, load_from="StockStatus"),
    }


class TaskSchema(schema.ResponseSchema):
    """Task -"""

    fields = {
        "AppVersionId": fields.Str(required=False, load_from="AppVersionId"),
        "BeginTime": fields.Int(required=True, load_from="BeginTime"),
        "EndTime": fields.Int(required=True, load_from="EndTime"),
        "ErrorMsg": fields.Str(required=True, load_from="ErrorMsg"),
        "ExecuteMsg": fields.Str(required=False, load_from="ExecuteMsg"),
        "State": fields.Str(required=True, load_from="State"),
        "TaskId": fields.Str(required=True, load_from="TaskId"),
        "UPhoneId": fields.Str(required=False, load_from="UPhoneId"),
    }


class JobSchema(schema.ResponseSchema):
    """Job -"""

    fields = {
        "AppVersionId": fields.Str(required=False, load_from="AppVersionId"),
        "BeginTime": fields.Int(required=False, load_from="BeginTime"),
        "CreateTime": fields.Int(required=False, load_from="CreateTime"),
        "EndTime": fields.Int(required=False, load_from="EndTime"),
        "JobId": fields.Str(required=False, load_from="JobId"),
        "JobType": fields.Str(required=False, load_from="JobType"),
        "State": fields.Str(required=False, load_from="State"),
        "Tasks": fields.List(TaskSchema()),
        "UPhoneIds": fields.List(fields.Str()),
    }


class UPhoneModelInstanceSchema(schema.ResponseSchema):
    """UPhoneModelInstance -"""

    fields = {
        "CPU": fields.Int(required=True, load_from="CPU"),
        "Description": fields.Str(required=False, load_from="Description"),
        "DiskSize": fields.Int(required=True, load_from="DiskSize"),
        "Dpi": fields.Int(required=False, load_from="Dpi"),
        "Memory": fields.Int(required=True, load_from="Memory"),
        "Refresh": fields.Int(required=True, load_from="Refresh"),
        "Resolution": fields.Str(required=True, load_from="Resolution"),
        "UPhoneModelName": fields.Str(
            required=True, load_from="UPhoneModelName"
        ),
    }


class ServerDiskSetSchema(schema.ResponseSchema):
    """ServerDiskSet -"""

    fields = {
        "DiskType": fields.Str(required=True, load_from="DiskType"),
        "IsBoot": fields.Bool(required=True, load_from="IsBoot"),
        "Size": fields.Int(required=True, load_from="Size"),
    }


class UPhoneSpecSchema(schema.ResponseSchema):
    """UPhoneSpec -"""

    fields = {
        "UPhoneCount": fields.Int(required=False, load_from="UPhoneCount"),
        "UPhoneModelName": fields.Str(
            required=False, load_from="UPhoneModelName"
        ),
    }


class ServerModelInstanceSchema(schema.ResponseSchema):
    """ServerModelInstance -"""

    fields = {
        "CPU": fields.Int(required=False, load_from="CPU"),
        "DiskSet": fields.List(ServerDiskSetSchema()),
        "GPU": fields.Int(required=False, load_from="GPU"),
        "GPUType": fields.Str(required=False, load_from="GPUType"),
        "Memory": fields.Int(required=False, load_from="Memory"),
        "ServerModelName": fields.Str(
            required=False, load_from="ServerModelName"
        ),
        "ServerModelState": fields.Str(
            required=False, load_from="ServerModelState"
        ),
        "UPhoneSpecs": fields.List(UPhoneSpecSchema()),
    }


class IpSetSchema(schema.ResponseSchema):
    """IpSet -"""

    fields = {
        "Ip": fields.Str(required=False, load_from="Ip"),
        "IpMode": fields.Str(required=False, load_from="IpMode"),
        "IpType": fields.Str(required=False, load_from="IpType"),
        "Isp": fields.Str(required=False, load_from="Isp"),
    }


class ServerInstanceSchema(schema.ResponseSchema):
    """ServerInstance -"""

    fields = {
        "ChargeType": fields.Str(required=True, load_from="ChargeType"),
        "CityId": fields.Str(required=True, load_from="CityId"),
        "CityName": fields.Str(required=True, load_from="CityName"),
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "ExpireTime": fields.Int(required=True, load_from="ExpireTime"),
        "IpSet": fields.List(IpSetSchema()),
        "ModifyTime": fields.Int(required=True, load_from="ModifyTime"),
        "Remark": fields.Str(required=False, load_from="Remark"),
        "ServerId": fields.Str(required=True, load_from="ServerId"),
        "ServerModel": ServerModelInstanceSchema(),
        "ServerName": fields.Str(required=True, load_from="ServerName"),
        "State": fields.Str(required=False, load_from="State"),
        "UPhoneCount": fields.Int(required=False, load_from="UPhoneCount"),
        "UPhoneModelName": fields.Str(
            required=True, load_from="UPhoneModelName"
        ),
    }


class StockInfoSchema(schema.ResponseSchema):
    """StockInfo - model的可用量信息"""

    fields = {
        "ModelName": fields.Str(required=False, load_from="ModelName"),
        "StockCount": fields.Int(required=False, load_from="StockCount"),
    }


class UPhoneAllowanceSchema(schema.ResponseSchema):
    """UPhoneAllowance - 云手机余量结构体"""

    fields = {
        "Allowance": fields.Int(required=True, load_from="Allowance"),
        "ModelName": fields.Str(required=True, load_from="ModelName"),
    }


class UPhonePriceSetSchema(schema.ResponseSchema):
    """UPhonePriceSet - 云手机价格列表"""

    fields = {
        "ChargeType": fields.Str(required=True, load_from="ChargeType"),
        "ListPrice": fields.Float(required=False, load_from="ListPrice"),
        "OriginalPrice": fields.Float(required=True, load_from="OriginalPrice"),
        "Price": fields.Float(required=True, load_from="Price"),
    }


class UPhoneServerPriceSetSchema(schema.ResponseSchema):
    """UPhoneServerPriceSet - 价格列表"""

    fields = {
        "ChargeType": fields.Str(required=True, load_from="ChargeType"),
        "ListPrice": fields.Float(required=False, load_from="ListPrice"),
        "OriginalPrice": fields.Float(required=True, load_from="OriginalPrice"),
        "Price": fields.Float(required=True, load_from="Price"),
    }


class UPhoneCommandResultSchema(schema.ResponseSchema):
    """UPhoneCommandResult -"""

    fields = {
        "ExecuteMsg": fields.Str(required=False, load_from="ExecuteMsg"),
        "UPhoneId": fields.Str(required=False, load_from="UPhoneId"),
    }


class ResultsSchema(schema.ResponseSchema):
    """Results -"""

    fields = {
        "ExecuteMsg": fields.Str(required=False, load_from="ExecuteMsg"),
        "UPhoneId": fields.Str(required=False, load_from="UPhoneId"),
    }
